#
# spec file for package apfel
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# PYTHON BINDINGS INCOMPATIBLE WITH PYTHON3
%if 0%{?suse_version} >= 1550
%bcond_with pywrap
%else
%bcond_without pywrap
%endif

%define skip_python3 1

%define soname libAPFEL0
Name:           apfel
Version:        3.0.4
Release:        bp153.1.71
Summary:        A Probability Distribution Function Evolution Library
License:        GPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            http://apfel.hepforge.org/
Source:         https://github.com/scarrazza/%{name}/archive/%{version}.tar.gz
# PATCH-FIX-UPSTREAM apfel-allow-disabling-pywrap.patch badshah400@gmail.com -- Allow building with python extension disabled, for example due to lack of python2 support in the system
Patch0:         apfel-allow-disabling-pywrap.patch
BuildRequires:  LHAPDF-devel
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  libboost_headers-devel
BuildRequires:  libtool
BuildRequires:  python-rpm-macros
%if %{with pywrap}
BuildRequires:  %{python_module LHAPDF}
BuildRequires:  %{python_module devel}
%endif
Requires:       python-LHAPDF

%python_subpackages

%description
APFEL is a library to perform the combined QCD+QED DGLAP
evolution of parton distributions.

%package -n %{soname}
Summary:        A Probability Distribution Function Evolution Library
Group:          System/Libraries

%description -n %{soname}
APFEL is a library to perform the combined QCD+QED DGLAP
evolution of parton distributions.

This package provides the shared libraries for %{name}.

%package -n %{name}-devel
Summary:        Development files for Apfel, a PDF Evolution Library
Group:          Development/Libraries/C and C++
Requires:       %{soname} = %{version}
Requires:       LHAPDF-devel
Recommends:     %{name}-doc = %{version}

%description -n %{name}-devel
APFEL is a library to perform the combined QCD+QED DGLAP
evolution of parton distributions.

This package provides the source files required to develop
applications with %{name}.

%package -n %{name}-doc
Summary:        Documentation for APFEL, a PDF evolution library
Group:          Documentation/Other

%description -n %{name}-doc
This package provides documentation for APFEL in PDF (Portable
Document Format), a PDF (Probability Distribution Function) evolution
library.

%prep
%autosetup -p1

%build
autoreconf -fvi
%configure \
  --disable-static \
  %{!?with_pywrap:--disable-pywrap}
make %{?_smp_mflags}

%install
%make_install

# REMOVE libtool ARCHIVES
find %{buildroot} -type f -name "*.la" -delete -print

# FIX env BASED SCRIPT INTERPRETER
sed -Ei "1{s|#\!\s*/usr/bin/env bash|#\!/bin/bash|}" %{buildroot}%{_bindir}/apfel-config

# REMOVE INSTALLED README, INSTALL IT USING %%doc INSTEAD
rm -fr %{buildroot}%{_datadir}/doc/apfel/README
rm -fr %{buildroot}%{_datadir}/apfel/README

%post   -n %{soname} -p /sbin/ldconfig
%postun -n %{soname} -p /sbin/ldconfig

%files -n %{soname}
%{_libdir}/*.so.*

%files -n %{name}-devel
%{_includedir}/APFEL/
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_bindir}/CheckAPFEL
%{_bindir}/%{name}-config
%{_bindir}/ListFunctions
%{_libdir}/*.so

%if %{with pywrap}
%files %{python_files}
%{_bindir}/apfel
%{python_sitearch}/*
%endif

%files -n %{name}-doc
%doc doc/pdfs/manual.pdf

%changelog
* Tue Apr 28 2020 Atri Bhattacharya <badshah400@gmail.com>
- Add apfel-allow-disabling-pywrap.patch to support building
  without building the python extensions and binaries; build
  python bindings and python-based binaries only for distributions
  supporting python2 since apfel does not support python3.
- Add libtool BuildRequires and run autoreconf since patch touches
  build files.
* Tue Jun 25 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.4:
  + New release for use with the latest version of HELL (no more
    changes documented by upstream).
* Sun Jan 13 2019 Jan Engelhardt <jengelh@inai.de>
- Update descriptions.
* Sat Jan 12 2019 badshah400@gmail.com
- Install pre-generated PDF manual as part of a new -doc package.
- Move ListFunctions binary into -devel package: apfel-config,
  already being installed as part of the devel package, is partly
  broken without this.
- Change `env` based script interpreter in apfel-config to
  directly call /bin/bash instead.
- Use %%%%license macro to install the license file.
- Run spec-cleaner for minor specfile cleanups
* Sat Jul 14 2018 badshah400@gmail.com
- Update to version 3.0.3:
  + Undocumented bug fixes.
* Mon Mar 26 2018 stefan.bruens@rwth-aachen.de
- Drop Qt4 BuildRequires, ApfelGUI has been deprecated in version 2.7
  and removed subsequently
- Build on all archs
* Sat Oct 28 2017 badshah400@gmail.com
- Update to version 3.0.2:
  + Update list-func function.
* Tue Jul 11 2017 badshah400@gmail.com
- Update to version 3.0.1:
  * Fixing bug in the upwards VFNS evolution of alpha.
* Wed Apr  5 2017 badshah400@gmail.com
- Update to version 3.0.0:
  * Implementation of the full NLO QCD+QED correction in the DGLAP
    evolution and in the DIS structure functions.
  * Interfacing APFEL to HELL (v.1.1) for the computation of the
    ZM small-x resummed structure functions.
  * Optimisation of the caching for PDFs and structure functions.
  * Completed external evolution operator when QED corrections are
    enabled.
  * Update of the documentation.
  * Clean up of the code.
  * Minor bug fixes and adjustments.
* Wed Apr  5 2017 badshah400@gmail.com
- Add BuildRequires: libboost_headers-devel or boost-devel as
  appropriate to the openSUSE versions to fix builds.
* Fri Jan 27 2017 bg@suse.com
- enable build on s390x
* Mon Aug  8 2016 badshah400@gmail.com
- Update to version 2.7.2:
  + Full intrinsic charm contributions up to O(as) in both NC and
    CC sectors.
  + Possibility to set the heavy quark thresholds different from
    the heavy quark masses in both the pole and the MSbar schemes.
  + New and more accurate parametrization of the O(as^2) NC
    massive coefficient functions over a wider range in Q^2.
  + Implementation of the cached PDF evolution.
  + Fix of minor bugs and minor improvements.
  + Update of the documentation.
- Upstream now also installs README in /usr/share/apfel; delete
  from both non-standard locations and use %%doc to package it
  instead.
* Mon Feb 15 2016 jengelh@inai.de
- Expand PDF acronym in summaries
- Drop author list from description, openSUSE does not do this
  since many many months.
* Tue Feb  2 2016 badshah400@gmail.com
- Update to version 2.7.0:
  + Implementation of the polarized evolution up to NNLO.
  + Implementation of the LO contribution to intrinsic charm in
    FONLL.
  + Possibility to perform dynamical factorization/renormalization
    scale variations.
  + New functions to feed higher order EW corrections.
  + Reduction of the memory footprint.
  + Speed up of the initialization phase.
  + Minor improvements and bug fixings.
- Changes from version 2.6.0:
  + Implementation of the factorization and renormalization scale
    variation for the DIS structure functions.
  + Implementation of a faster solution for the QCD+QED unified
    solution of the DGLAP equation.
  + Improving the production of the LHAPDF grids.
  + Improving the accuracy of the truncated solution of the DGLAP
    equation (from 3- to 5-point derivative).
  + Colorful banner.
  + Minor improvements.
- Apfelgui is deprecated, drop all supporting files:
  +  apfelgui.changes.
  +  pre_checkin.sh.
  +  apfelgui.spec.
  +  apfelgui.spec.in.
  +  README.
* Thu Jul  9 2015 badshah400@gmail.com
- Update to version 2.5.2:
  + Implementation of truncated PDF evolution.
  + libAPFELevol: a light version of APFEL with just evolution.
  + general code improvements.
  + Fixed bugs:
  - Fixed bug in the computation of the SIA cross-sections.
  - Fixed xmax and xmin tolerance.
- Changes from previous versions 2.3.4 through 2.4.0:
  + See https://github.com/scarrazza/apfel/releases.
* Fri Mar 20 2015 badshah400@gmail.com
- Update to version 2.3.3:
  + Functions for the production of FK tables.
  + Updated format of the output LHAPDF grids.
  + Implementation of semi-inclusive e^+e^- annihilation structure
    functions,
  + Added flag to the apfel-config script to list the APFEL
    functions.
- Changes from previous versions:
  + Long list of changes since previous packaged version, see NEWS
    file.
- Packaging changes: Use LHAPDF 6.x (instead of 5.x) for building,
  since apfel is now LHAPDFv6 compatible.
- Since version 2.3.0, building on 32-bit architectures is
  unsupported by upstream.
* Thu May  1 2014 badshah400@gmail.com
- apfelgui: Requires(post) and Requires(postun) should be on
  desktop-file-utils (for %%desktop_database_post(un) scriptlets)
  rather than on update-desktop-files.
* Tue Apr 29 2014 badshah400@gmail.com
- apfel-devel should have a "Requires:" on lhapdf-devel <= 5.9.1.
* Sat Apr 19 2014 badshah400@gmail.com
- Build and install hicolor icons (introduces a BuildRequires on
  hicolor-icon-theme) and desktop menu entry.
* Sun Apr 13 2014 badshah400@gmail.com
- Initial package (version 2.0.1).
